==> better-translation-0.0.1.tar.gz: better-translation-0.0.1/better_translation/integrations/django/models.py <==
from __future__ import annotations

from typing import cast
from uuid import uuid4

try:
    from django.db import models
except ImportError as e:
    msg = "Django is not installed. To use Django integration, install Django."
    raise ValueError(msg) from e


MAX_MESSAGE_LENGTH = 4096


class DefaultLocalesChoices(models.TextChoices):
    RU = "ru", "Russian"
    EN = "en", "English"


class BaseMessage(models.Model):
    id = models.UUIDField(
        primary_key=True,
        default=uuid4,
        editable=False,
    )

    raw_singular = models.CharField(
        max_length=MAX_MESSAGE_LENGTH,
        verbose_name="Raw singular form of the message",
        unique=True,
    )

    raw_plural = models.CharField(
        max_length=MAX_MESSAGE_LENGTH,
        verbose_name="Raw plural form of the message",
        default="",
    )

    is_used = models.BooleanField(
        verbose_name="Is used",
        default=True,
    )

    translations: models.QuerySet[BaseTranslation]
    """A QuerySet of translations for this message."""

    def __str__(self) -> str:
        return f"Message: {self.raw_singular}"

    class _Meta:
        abstract = True

    Meta = cast("type[models.Model.Meta]", _Meta)


class BaseTranslation(models.Model):
    locale = models.CharField(
        max_length=5,
        verbose_name="Locale",
        choices=DefaultLocalesChoices.choices,
    )
    singular = models.TextField(
        verbose_name="Singular form of the text",
    )
    plural = models.TextField(
        verbose_name="Plural form of the text",
        default="",
        blank=True,
    )

    message = models.ForeignKey(
        BaseMessage,
        on_delete=models.CASCADE,
        related_name="translations",
    )

    def __str__(self) -> str:
        return f"MessageTranslation({self.locale})"

    class _Meta:
        abstract = True

    Meta = cast("type[models.Model.Meta]", _Meta)

==> better-translation-0.2.0.tar.gz: better-translation-0.2.0/better_translation/integrations/django/models.py <==
from __future__ import annotations

from typing import cast

try:
    from django.db import models
except ImportError as e:
    msg = "Django is not installed. To use Django integration, install Django."
    raise ValueError(msg) from e


class DefaultLocalesChoices(models.TextChoices):
    RU = "ru", "Russian"
    EN = "en", "English"


class BaseMessage(models.Model):
    id = models.CharField(max_length=255, primary_key=True)
    default = models.TextField(
        verbose_name="Default singular form of the message",
    )
    default_plural = models.TextField(
        verbose_name="Default plural form of the message",
    )
    is_used = models.BooleanField(verbose_name="Is used", default=True)

    translations: models.QuerySet[BaseTranslation]
    """A QuerySet of translations for this message."""

    def __str__(self) -> str:
        return f"Message: {self.id}"

    def __eq__(self, other: object) -> bool:
        if not isinstance(other, BaseMessage):
            return False

        return self.id == other.id

    def __hash__(self) -> int:
        return hash(self.id)

    class _Meta:
        abstract = True

    Meta = cast("type[models.Model.Meta]", _Meta)


class BaseTranslation(models.Model):
    locale = models.CharField(
        max_length=5,
        verbose_name="Locale",
        choices=DefaultLocalesChoices.choices,
    )
    singular = models.TextField(verbose_name="Singular form of the text")
    plural = models.TextField(
        verbose_name="Plural form of the text",
        default="",
        blank=True,
    )

    message = models.ForeignKey(
        BaseMessage,
        on_delete=models.CASCADE,
        related_name="translations",
    )

    def __str__(self) -> str:
        return f"MessageTranslation('{self.locale}', '{self.singular[:10]}...')"

    class _Meta:
        abstract = True

    Meta = cast("type[models.Model.Meta]", _Meta)
